==> touhoulittlemaid-fabric-1.21.1-0.1.7.2-neo1.3.8-sources.jar: com/github/tartaricacid/touhoulittlemaid/client/gui/entity/maid/backpack/EmptyBackpackContainerScreen.java <==
package com.github.tartaricacid.touhoulittlemaid.client.gui.entity.maid.backpack;

import com.github.tartaricacid.touhoulittlemaid.TouhouLittleMaid;
import com.github.tartaricacid.touhoulittlemaid.client.gui.entity.maid.AbstractMaidContainerGui;
import com.github.tartaricacid.touhoulittlemaid.entity.passive.EntityMaid;
import com.github.tartaricacid.touhoulittlemaid.inventory.container.backpack.EmptyBackpackContainer;
import com.mojang.blaze3d.systems.RenderSystem;
import net.minecraft.class_1661;
import net.minecraft.class_2561;
import net.minecraft.class_2960;
import net.minecraft.class_332;
import net.minecraft.class_757;
import org.anti_ad.mc.ipn.api.IPNButton;
import org.anti_ad.mc.ipn.api.IPNGuiHint;
import org.anti_ad.mc.ipn.api.IPNPlayerSideOnly;

@IPNPlayerSideOnly
@IPNGuiHint(button = IPNButton.SORT, horizontalOffset = -36, bottom = -12)
@IPNGuiHint(button = IPNButton.SORT_COLUMNS, horizontalOffset = -24, bottom = -24)
@IPNGuiHint(button = IPNButton.SORT_ROWS, horizontalOffset = -12, bottom = -36)
@IPNGuiHint(button = IPNButton.SHOW_EDITOR, horizontalOffset = -5)
@IPNGuiHint(button = IPNButton.SETTINGS, horizontalOffset = -5)
public class EmptyBackpackContainerScreen extends AbstractMaidContainerGui<EmptyBackpackContainer> implements IBackpackContainerScreen {
    private static final class_2960 BACKPACK = class_2960.method_60655(TouhouLittleMaid.MOD_ID, "textures/gui/maid_gui_backpack.png");
    private final EntityMaid maid;

    public EmptyBackpackContainerScreen(EmptyBackpackContainer container, class_1661 inv, class_2561 titleIn) {
        super(container, inv, titleIn);
        this.field_2779 = 256;
        this.field_2792 = 256;
        this.maid = field_2797.getMaid();
    }

    @Override
    protected void method_2389(class_332 graphics, float partialTicks, int x, int y) {
        super.method_2389(graphics, partialTicks, x, y);
        RenderSystem.setShader(class_757::method_34542);
        RenderSystem.setShaderTexture(0, BACKPACK);
        graphics.method_25302(BACKPACK, field_2776 + 85, field_2800 + 36, 0, 0, 165, 128);
        graphics.method_25294(field_2776 + 142, field_2800 + 58, field_2776 + 250, field_2800 + 76, 0xaa222222);
        graphics.method_25302(BACKPACK, field_2776 + 190, field_2800 + 62, 165, 0, 11, 11);
        graphics.method_25294(field_2776 + 142, field_2800 + 81, field_2776 + 250, field_2800 + 117, 0xaa222222);
        graphics.method_25302(BACKPACK, field_2776 + 190, field_2800 + 92, 165, 0, 11, 11);
        graphics.method_25294(field_2776 + 142, field_2800 + 122, field_2776 + 250, field_2800 + 158, 0xaa222222);
        graphics.method_25302(BACKPACK, field_2776 + 190, field_2800 + 133, 165, 0, 11, 11);
    }
}

==> touhoulittlemaid-fabric-1.21.1-0.2.0-neo1.4.2-sources.jar: com/github/tartaricacid/touhoulittlemaid/client/gui/entity/maid/backpack/EmptyBackpackContainerScreen.java <==
package com.github.tartaricacid.touhoulittlemaid.client.gui.entity.maid.backpack;

import com.github.tartaricacid.touhoulittlemaid.TouhouLittleMaid;
import com.github.tartaricacid.touhoulittlemaid.client.gui.entity.maid.AbstractMaidContainerGui;
import com.github.tartaricacid.touhoulittlemaid.client.gui.widget.button.BaubleButton;
import com.github.tartaricacid.touhoulittlemaid.entity.passive.EntityMaid;
import com.github.tartaricacid.touhoulittlemaid.inventory.container.backpack.EmptyBackpackContainer;
import com.mojang.blaze3d.systems.RenderSystem;
import net.minecraft.class_1661;
import net.minecraft.class_2561;
import net.minecraft.class_2960;
import net.minecraft.class_332;
import net.minecraft.class_757;
import org.anti_ad.mc.ipn.api.IPNButton;
import org.anti_ad.mc.ipn.api.IPNGuiHint;
import org.anti_ad.mc.ipn.api.IPNPlayerSideOnly;

@IPNPlayerSideOnly
@IPNGuiHint(button = IPNButton.SORT, horizontalOffset = -36, bottom = -12)
@IPNGuiHint(button = IPNButton.SORT_COLUMNS, horizontalOffset = -24, bottom = -24)
@IPNGuiHint(button = IPNButton.SORT_ROWS, horizontalOffset = -12, bottom = -36)
@IPNGuiHint(button = IPNButton.SHOW_EDITOR, horizontalOffset = -5)
@IPNGuiHint(button = IPNButton.SETTINGS, horizontalOffset = -5)
public class EmptyBackpackContainerScreen extends AbstractMaidContainerGui<EmptyBackpackContainer> implements IBackpackContainerScreen {
    private static final class_2960 BACKPACK = class_2960.method_60655(TouhouLittleMaid.MOD_ID, "textures/gui/maid_gui_backpack.png");
    private final EntityMaid maid;

    public EmptyBackpackContainerScreen(EmptyBackpackContainer container, class_1661 inv, class_2561 titleIn) {
        super(container, inv, titleIn);
        this.field_2779 = 256;
        this.field_2792 = 256;
        this.maid = field_2797.getMaid();
    }

    @Override
    protected void initAdditionWidgets() {
        BaubleButton button = this.getBaubleButton(maid, field_2776, field_2800);
        this.method_37063(button);
    }

    @Override
    protected void method_2389(class_332 graphics, float partialTicks, int x, int y) {
        super.method_2389(graphics, partialTicks, x, y);
        RenderSystem.setShader(class_757::method_34542);
        RenderSystem.setShaderTexture(0, BACKPACK);
        graphics.method_25302(BACKPACK, field_2776 + 85, field_2800 + 36, 0, 0, 165, 128);
        graphics.method_25294(field_2776 + 142, field_2800 + 58, field_2776 + 250, field_2800 + 76, 0xaa222222);
        graphics.method_25302(BACKPACK, field_2776 + 190, field_2800 + 62, 165, 0, 11, 11);
        graphics.method_25294(field_2776 + 142, field_2800 + 81, field_2776 + 250, field_2800 + 117, 0xaa222222);
        graphics.method_25302(BACKPACK, field_2776 + 190, field_2800 + 92, 165, 0, 11, 11);
        graphics.method_25294(field_2776 + 142, field_2800 + 122, field_2776 + 250, field_2800 + 158, 0xaa222222);
        graphics.method_25302(BACKPACK, field_2776 + 190, field_2800 + 133, 165, 0, 11, 11);
    }
}
